/*
 * Copyright 2000-2008 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package bzr4idea.actions;

import bzr4idea.commands.BzrImpl;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.VcsException;
import com.intellij.openapi.vcs.update.ActionInfo;
import com.intellij.openapi.vfs.VirtualFile;
import bzr4idea.BzrRevisionNumber;
import bzr4idea.commands.GitHandlerUtil;
import bzr4idea.i18n.GitBundle;
import bzr4idea.merge.GitMergeUtil;
import bzr4idea.merge.GitPullDialog;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.Set;

import bzr4idea.BzrException;
import bzr4idea.util.IdeaHelper;

/**
 * Git "pull" action
 */
public class GitPull extends GitRepositoryAction {

  /**
   * {@inheritDoc}
   */
  @Override
  @NotNull
  protected String getActionName() {
    return GitBundle.getString("pull.action.name");
  }

  /**
   * {@inheritDoc}
   */
  protected void perform(@NotNull final Project project,
                         @NotNull final List<VirtualFile> gitRoots,
                         @NotNull final VirtualFile defaultRoot,
                         final Set<VirtualFile> affectedRoots,
                         final List<VcsException> exceptions) throws VcsException {

    final GitPullDialog dialog = new GitPullDialog(project, gitRoots, defaultRoot);
    dialog.show();
    if (!dialog.isOK()) {
      return;
    }
    /* bzr4idea
    GitLineHandler h = dialog.pullHandler();
    */
    final VirtualFile root = dialog.gitRoot();
    affectedRoots.add(root);
    BzrRevisionNumber currentRev = BzrRevisionNumber.resolve(project, root, BzrRevisionNumber.TIP );
    /* bzr4idea
    try {
      GitHandlerUtil.doSynchronously(h, GitBundle.message("pulling.title", dialog.getRemote()), h.printableCommandLine());
    }
    finally {
      /* bzr4idea:
      exceptions.addAll(h.errors());
    }
    if (exceptions.size() != 0) {
      return;
    }
    */
    IdeaHelper.addAll( exceptions, GitHandlerUtil.doSynchronously( new GitHandlerUtil.BzrSynchronousRunner(
                                     GitBundle.message("pulling.title", dialog.getRemoteTextField().getText()),
                                     BzrImpl.forBzrRoot(root), project ){
                                   protected void run(BzrImpl bzr) throws BzrException {
                                     bzr.pull( dialog.getSourceBranchLocation(), dialog.getPullOptions() );
                                   }
                                 } ) );
    if ( exceptions.isEmpty() ) {
      GitMergeUtil.showUpdates(project, exceptions, root, currentRev, getActionName(), ActionInfo.UPDATE);
    }
  }

}
